<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" 
            doctype-public="-//W3C//DTD XHTML 1.1//EN" doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd" />
<xsl:preserve-space elements="*" />

<!-- The outer template for the page -->
<xsl:template match="webpage">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
 <head>
   <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
   <!--
   <base href="http://www.srcf.ucam.org/assassins/" />
   <link rel="stylesheet" type="text/css" href="assassins.css" />
   -->
   <link rel="stylesheet" type="text/css" href="http://www.srcf.ucam.org/assassins/assassins.css"/>
   <link rel="shortcut icon" href="http://www.srcf.ucam.org/assassins/assassins-favicon.png" />
   <title>The Assassins' Guild - <xsl:value-of select="title/text()" /></title>
 </head>
 <body>
  
   <!-- The header -->
   <hr />
   <h1>
      <img class="dagger" src="img/cloak2.gif" alt="Cloak &amp; Dagger" /> 
      The Assassins' Guild - <xsl:value-of select="title/text()" />
   </h1>
   <hr />

   <!-- The page 
        All the content goes in here -->   

   <xsl:apply-templates />

   <!-- The Footer -->
   
   <hr />   
   <p class="center">
      | <a href="/assassins/">Home</a> || <a href="mailto:assassins@srcf.ucam.org">Email</a> |
      <br />
      <!-- print out the linxs to the other pages -->
      <xsl:for-each select="links/a">| <xsl:copy-of select="." /> |</xsl:for-each>

      <br />
      <a href="http://validator.w3.org/check/referer"><img 
         src="img/valid-xhtml11.png" alt="Valid XHTML 1.1" /></a>
   </p>
   <hr />

 </body>
</html>
</xsl:template>

<!-- Ignore the title node -->
<xsl:template match="title">
</xsl:template>

<!-- Ignore the links node -->
<xsl:template match="links">
</xsl:template>

<!-- This contains HTML, copy all nodes below it into the output -->
<xsl:template match="html">
 <xsl:apply-templates />
</xsl:template>

<!-- Copy everything under a html -->
<xsl:template match="html/*">
 <xsl:copy-of select="." />
</xsl:template>

<!-- This contains non-block-level HTML, 
   copy all nodes below it into the output in a <p> -->
<xsl:template match="text">
 <p>
  <xsl:apply-templates />
 </p>
</xsl:template>

<!-- Interpret colour nodes -->
<xsl:template match="text//colour"><span class="colour{@type}"><xsl:apply-templates /></span></xsl:template>

<!-- Copy everything under a text-->
<xsl:template match="text//*">
 <xsl:copy><xsl:apply-templates /></xsl:copy>
</xsl:template>


<!-- Events block, doesn't need any special markup -->
<xsl:template match="events">
 <xsl:apply-templates />
</xsl:template>

<!-- Start of each day is a heading -->
<xsl:template match="day">
 <h3><xsl:value-of select="." /></h3>
</xsl:template>

<!-- Put a block around each event, and lines around the heading -->
<xsl:template match="event">
 <div class="event">
  <hr />
  <span>
  <xsl:attribute name="id">
   <xsl:apply-templates select="anchor"/>
  </xsl:attribute>
  [<xsl:value-of select="time/text()"/>]
  <xsl:text> </xsl:text>
  <xsl:apply-templates select="headline"/>
  </span>
  <hr />
  <xsl:apply-templates select="reports" />
 </div>
</xsl:template>

<!-- Do this slightly differently on head/hups for more compact appearance -->
<xsl:template match="event-summary">
 <span class="event">
  [<a><xsl:attribute name="href">
    <xsl:value-of select="reference/@page"/>#e<xsl:value-of select="reference/@event"/>
   </xsl:attribute><xsl:value-of select="time/text()"/></a>]
  <xsl:text> </xsl:text>
  <xsl:apply-templates select="headline"/>
  <br/>
 </span>
</xsl:template>

<!-- Do funny substitution on colour tags -->
<xsl:template match="colour"><span><xsl:attribute name="class">colour<xsl:value-of select="./@type" /></xsl:attribute><xsl:value-of select="."/></span></xsl:template>

<!-- Headline in an inline element -->
<xsl:template match="headline">
 <span class="headline"><xsl:apply-templates /></span>
</xsl:template>

<!-- Reports block, doesn't need any special markup -->
<xsl:template match="reports">
 <xsl:apply-templates />
</xsl:template>

<!-- Each report in a block-level element -->
<xsl:template match="report">
 <div class="report">
  <xsl:apply-templates select="pseudonym" />
  <div class="indent">
   <span><xsl:attribute name="class">colour<xsl:value-of select="./@colour" /></xsl:attribute><xsl:apply-templates select="text" /></span>
  </div>
 </div>
</xsl:template>

<xsl:template match="pseudonym">
  <span><xsl:attribute name="class">colour<xsl:value-of select="./@colour" /></xsl:attribute><xsl:value-of select="." /></span> reports: <br />
</xsl:template>
  
<!-- just copy the table of players - thats done -->
<xsl:template match="table">
 <xsl:copy-of select="." />
</xsl:template>

</xsl:stylesheet>

